Index | django_cradmin API Document

# References

## Class Summary

Static Public Class Summary
public | AbstractDataListWidget |
public | AbstractSelectWidget |
public | ApiDataListWidget |
public | AutoSubmitFormAfterCountdownWidget Autosubmit form after a timeout widget. |
public | CalendarCoordinator Coordinates the common calendar data no matter what kind of view we present. |
public | CradminDateSelectorDay |
public | CradminDateSelectorHiddenIsoDate |
public | CradminDateSelectorMonth |
public | CradminDateSelectorYear |
public | CradminFilterCheckbox |
public | CradminHiddenInputList |
public | CradminHtmlList |
public | CradminLoadMoreButton |
public | CradminSearchInput |
public | CradminSelectableList |
public | CradminSelectableListItem |
public | CradminSelectedList |
public | CradminSelectedListItem |
public | DataListDisplayByStateWidget |
public | DateSelectorDayWidget |
public | DateSelectorHiddenIsoDateWidget |
public | DateSelectorMonthWidget |
public | DateSelectorYearWidget |
public | DateTimePicker |
public | DjangoCradminAll |
public | DomUtilities General purpose DOM utilities. |
public | ElementCreator |
public | FilterCheckboxFilter |
public | HiddenInputListWidget |
public | HidePopupOnClickWidget |
public | HtmlListWidget |
public | LoadMoreButtonWidget |
public | MenuToggleWidget |
public | MonthlyCalendarCoordinator Coordinates the common calendar data for a month-view. |
public | PopUpWidget |
public | PrintOnClickWidget Run `window.print()` on click widget. |
public | SearchInputWidget |
public | SelectableListWidget |
public | SelectedListWidget |
public | ShowPopupOnClickWidget |
public | SignalRouterWidget |
public | StaticDataListWidget |
public | TabButtonWidget |
public | TabPanelWidget |
public | ToggleableMenuWidget |